diff --git a/api/@ohos.abilityAccessCtrl.d.ts b/api/@ohos.abilityAccessCtrl.d.ts
index 563b13cdb..cefab32ec 100644
--- a/api/@ohos.abilityAccessCtrl.d.ts
+++ b/api/@ohos.abilityAccessCtrl.d.ts
@@ -536,7 +536,7 @@ declare namespace abilityAccessCtrl {
*
* @param { Context } context - The context that initiates the permission request.
*
The context must belong to the Stage model and only supports UIAbilityContext and UIExtensionContext.
* @param { Array } permissionNameList - Indicates the list of permission to be requested. This parameter cannot be null or empty.
* @returns { Promise> } Returns the list of status of the specified permission.
* @throws { BusinessError } 401 - Parameter error. Possible causes: 1. Mandatory parameters are left unspecified; 2. Incorrect parameter types.
* @throws { BusinessError } 12100001 - Invalid parameter. Possible causes: 1. The context is invalid because it does not belong to the application itself;
@@ -549,7 +549,7 @@ declare namespace abilityAccessCtrl {
* @atomicservice
* @since 12
*/
- requestPermissionOnSetting(context: Context, permissionNameList: Array): Promise>;
+ requestPermissionOnSetting(context: Context, permissionList: Array): Promise>;
/**
* Requests certain global switch status on setting from the user.
@@ -536,7 +536,7 @@ declare namespace abilityAccessCtrl {
*
The context must belong to the Stage model and only supports UIAbilityContext and UIExtensionContext.
- * @param { Array } permissionNameList - Indicates the list of permission to be requested. This parameter cannot be null or empty.
+ * @param { Array } permissionList - Indicates the list of permission to be requested. This parameter cannot be null or empty.
* @returns { Promise> } Returns the list of status of the specified permission.
* @throws { BusinessError } 401 - Parameter error. Possible causes: 1. Mandatory parameters are left unspecified; 2. Incorrect parameter types.